@@ -19,16 +19,12 @@
 #define LISPEXPORT
 #define LISPIMPORT
 
-// Number of bits in long
-#define BITS_PER_LONG 64
-
-
 // Number of bits to use for reference-counting. This can actually
 // grow significantly, when sub-expressions are copied (in which
 // case a LispSubList references the same sequence of LispObjects!)
-#define ReferenceBits 32
+#define ReferenceBits 64
 #define ReferenceType unsigned int
-#define ReferenceMax ((unsigned int)0xffffffff)
+#define ReferenceMax ((unsigned int)0xffffffffffffffff)
 
 
 // Platform-independent booleans
